@@ -116,7 +116,7 @@ class ZbxCommon(object):
         self.machine_id=''
         self.server=server_url
         self.config={}
-        self.param={}
+        self.args={}
         self.log=logger
         self.obj_token=''
         self.auth_uuid=''
@@ -773,12 +773,12 @@ class ZbxCommon(object):
             return ""
 
     def get_param(self,key=''):
-        if len(self.param)==0 and len(sys.argv)==2 and len(sys.argv[1])==36:
-            self.param=self.params({'k':sys.argv[1]})
+        if len(self.args)==0 and len(sys.argv)==2 and len(sys.argv[1])==36:
+            self.args=self.params({'k':sys.argv[1]})
         if key=='':
-            return self.param
+            return self.args
         else:
-            return self.param.get(key,'')
+            return self.args.get(key, '')
 
 
 
@@ -791,7 +791,7 @@ class ZbxCommon(object):
         # params=self.execute('cli params -k %s'%(key))
         params=self.params({'k':key})
         if isinstance(params,dict):
-            self.param=params
+            self.args=params
         if not isinstance(params,dict) and force_exit:
             logger.warning('params is not dict')
             sys.exit(1)
@@ -1410,7 +1410,7 @@ HELP_DOC='''
 
 
         ##### 内置工具函数　#####
-        # cli.params.get('name) #获取命令行参数
+        # cli.args.get('name) #获取命令行参数
         # cli.id() #获取机器标识（uuid） 与  cli.get_machine_id() 相同
         # cli.get_machine_id() #获取机器标识（uuid）
         # cli.ip() #获取本机ip
